
RELEASE_VERSION='0.3.1420153260'
BUILD_DATE='Tue Aug 20 15:10:54 UTC 2024'
BUILD_MACHINE_INFO='Linux runner-ykxhnyexq-project-28359933-concurrent-0 5.15.154+ #1 SMP Sat May 4 12:14:42 UTC 2024 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='7623238600'
GIT_COMMIT_SHA='cda0d0f66e3fe6ee08946dbb4e151eea6bd622f2'
GIT_BRANCH='main'
